function sig = pv_func(fm_mat, hopsize)
%Inputs:	fm_mat - the matrix of STFT coefficients
%			hopsize - the shift between successive windows
%Outputs	sig - the correct coefficients

%getting matrix dimensions
s = size(fm_mat);
num_iter = s(1);
fm_len = s(2);
window_size = fm_len;

%prime the loop 
prev_pha = 0;
pha_cumulative = 0;
true_freq = 0;
new_fm_mat = zeros(size(fm_mat));

for iter = 1:num_iter
	mag_pha = abs(fm_mat(iter,:));		%convert to polar coordinates
	ang_pha = angle(fm_mat(iter,:));
	
	d_pha = ang_pha - prev_pha;		%get the phase difference
	prev_pha = ang_pha;
	
	d_pha_prime = d_pha - hopsize * 2*pi*(0:(window_size-1))/window_size;	%subtract off expected phase
	d_wrapped_pha = mod(d_pha_prime + pi, 2*pi) - pi;		%wrap it to -pi, pi
	true_freq = 2*pi*(0:(window_size-1))/window_size + d_wrapped_pha/hopsize;	%add to binned frequency to get the true one
	new_fm_mat(iter,:) = mag_pha.*exp(i*true_freq);;
end

sig = new_fm_mat;